summaryrefslogtreecommitdiff
path: root/include/SFML/Network/TcpListener.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'include/SFML/Network/TcpListener.hpp')
-rw-r--r--include/SFML/Network/TcpListener.hpp8
1 files changed, 5 insertions, 3 deletions
diff --git a/include/SFML/Network/TcpListener.hpp b/include/SFML/Network/TcpListener.hpp
index a46ef29..1115eef 100644
--- a/include/SFML/Network/TcpListener.hpp
+++ b/include/SFML/Network/TcpListener.hpp
@@ -1,7 +1,7 @@
////////////////////////////////////////////////////////////
//
// SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2015 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2016 Laurent Gomila (laurent@sfml-dev.org)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
@@ -30,6 +30,7 @@
////////////////////////////////////////////////////////////
#include <SFML/Network/Export.hpp>
#include <SFML/Network/Socket.hpp>
+#include <SFML/Network/IpAddress.hpp>
namespace sf
@@ -71,14 +72,15 @@ public:
/// If the socket was previously listening to another port,
/// it will be stopped first and bound to the new port.
///
/// \param port Port to listen for new connections
///
/// \return Status code
///
/// \see accept, close
///
////////////////////////////////////////////////////////////
- Status listen(unsigned short port);
+ Status listen(unsigned short port, const IpAddress& address = IpAddress::Any);
////////////////////////////////////////////////////////////
/// \brief Stop listening and close the socket
@@ -71,14 +72,15 @@ public:
/// it will be stopped first and bound to the new port.
///
- /// \param port Port to listen for new connections
+ /// \param port Port to listen for new connections
+ /// \param address Address of the interface to listen on
///
/// \return Status code